@@ -128,6 +128,7 @@
 #' in ch for an unobservable state except for RDMSOccRepro which is used to specify strata ordering (eg 0 not-occupied, 1 occupied no repro, 2 occupied with repro.
 #' @param counts named list of numeric vectors (one group) or matrices (>1
 #' group) containing counts for mark-resight models
+#' @param icvalues numeric vector of individual covariate values for computation of real values
 #' @return model: a MARK object containing output and extracted results. It is
 #' a list with the following elements \item{data}{name of the processed data
 #' frame} \item{model}{type of analysis model (see list above)}
@@ -198,14 +199,14 @@
 #' @examples
 #' 
 #' data(dipper)
-#' dipper.Phidot.pdot=mark(dipper)
+#' dipper.Phidot.pdot=mark(dipper,threads=1)
 #' 
 mark <-
 function(data,ddl=NULL,begin.time=1,model.name=NULL,model="CJS",title="",model.parameters=list(),initial=NULL,
 design.parameters=list(), right=TRUE, groups = NULL, age.var = NULL, initial.ages = 0, age.unit = 1, time.intervals = NULL,nocc=NULL,output=TRUE,
 invisible=TRUE,adjust=TRUE,mixtures=1,se=FALSE,filename=NULL,prefix="mark",default.fixed=TRUE,silent=FALSE,retry=0,options=NULL,brief=FALSE,
 realvcv=FALSE,delete=FALSE,external=FALSE,profile.int=FALSE,chat=NULL,reverse=FALSE,run=TRUE,input.links=NULL,parm.specific=FALSE,mlogit0=FALSE,threads=-1,hessian=FALSE,accumulate=TRUE,
-allgroups=FALSE,strata.labels=NULL,counts=NULL)
+allgroups=FALSE,strata.labels=NULL,counts=NULL,icvalues=NULL)
 {
 #
 #  If the data haven't been processed (data$data is NULL) do it now with specified or default arguments
@@ -256,7 +257,8 @@ while(i<=retry & !converge)
       model<-try(make.mark.model(data.proc,title=title,parameters=model.parameters,
              ddl=ddl,initial=initial,call=match.call(),default.fixed=default.fixed,
              model.name=model.name,options=options,profile.int=profile.int,chat=chat,
-			 input.links=input.links,parm.specific=parm.specific,mlogit0=mlogit0,hessian=hessian,accumulate=accumulate))
+			 input.links=input.links,parm.specific=parm.specific,mlogit0=mlogit0,hessian=hessian,
+			 accumulate=accumulate,icvalues=icvalues))
       if(class(model)[1]=="try-error")
 	  {
 		  stop("Misspecification of model or internal error in code")
@@ -278,10 +280,13 @@ while(i<=retry & !converge)
 #
 # Run model
 #
-   runmodel<-run.mark.model(model,invisible=invisible,adjust=adjust,filename=filename,prefix=prefix,realvcv=realvcv,delete=delete,threads=threads,ignore.stderr=silent)
+   if(silent)
+	   runmodel<-suppressMessages(run.mark.model(model,invisible=invisible,adjust=adjust,filename=filename,prefix=prefix,realvcv=realvcv,delete=delete,threads=threads,ignore.stderr=silent))
+   else
+       runmodel<-run.mark.model(model,invisible=invisible,adjust=adjust,filename=filename,prefix=prefix,realvcv=realvcv,delete=delete,threads=threads,ignore.stderr=silent)
    if(is.null(runmodel))
    {
-     cat("\n\n********Following model failed to run :",model$model.name,"**********\n\n")
+     if(!silent)message("\n\n********Following model failed to run :",model$model.name,"**********\n\n")
      return(invisible())
    }
    else
@@ -292,7 +297,7 @@ while(i<=retry & !converge)
 #
       if(retry>0 && !is.null(runmodel$results$singular))
       {
-         message("\nRe-running analysis with new starting values\n")
+		 if(!silent)message("\nRe-running analysis with new starting values\n")
          i=i+1
          converge=FALSE
          initial=runmodel$results$beta$estimate
